@@ -2,6 +2,22 @@ require 'puppetlabs_spec_helper/module_spec_helper'
 require 'rspec-puppet-facts'
 include RspecPuppetFacts
 
+if Dir.exist?(File.expand_path('../../lib', __FILE__))
+  require 'coveralls'
+  require 'simplecov'
+  require 'simplecov-console'
+  SimpleCov.formatters = [
+    SimpleCov::Formatter::HTMLFormatter,
+    SimpleCov::Formatter::Console
+  ]
+  SimpleCov.start do
+    track_files 'lib/**/*.rb'
+    add_filter '/spec'
+    add_filter '/vendor'
+    add_filter '/.vendor'
+  end
+end
+
 RSpec.configure do |c|
   default_facts = {
     puppetversion: Puppet.version,
@@ -12,5 +28,6 @@ RSpec.configure do |c|
   c.default_facts = default_facts
 end
 
+require 'spec_helper_corosync'
 require 'spec_helper_methods'
 # vim: syntax=ruby
